RequestError

Enum RequestError 

pub enum RequestError {
    BadRequest {
        name: String,
        violations: Vec<PathError>,
    },
    Path(PathError),
    Generic(GenericErrorBox),
    Encode(EncodeError),
    Decode(DecodeError),
}
Request error types.

Variants



BadRequest

Invalid request with field violations.

Fields

name: String

Request name.

violations: Vec<PathError>

Field violations.



Path(PathError)

Path-specific error.



Generic(GenericErrorBox)

Generic error.



Encode(EncodeError)

Encode error.



Decode(DecodeError)

Decode error.

Implementations

Source

impl RequestError

pub fn bad_request<N, V, F, E>(name: N, violations: V) -> Self
where N: Display, V: IntoIterator<Item = (F, E)>, F: Display, E: Into<GenericErrorBox>,

Creates a bad request error.

pub fn generic<E: Into<GenericErrorBox>>(error: E) -> Self

Creates a generic error.

pub fn path<P, E>(path: P, error: E) -> Self

Creates a path error.

pub fn field<F, E>(field: F, error: E) -> Self

Creates a field error.

pub fn field_index<F, E>(field: F, index: usize, error: E) -> Self

Creates a field index error.

pub fn field_key<F, K, E>(field: F, key: K, error: E) -> Self
where F: Display, K: Display, E: Into<GenericErrorBox>,

Creates a field key error.

pub fn field_parse<F, E>(field: F, error: E) -> Self

Creates a field parse error.

pub fn index<E>(index: usize, error: E) -> Self

Creates an index error.

pub fn key<K, E>(key: K, error: E) -> Self

Creates a key error.

pub fn wrap_path<P>(self, path: P) -> Self
where P: IntoIterator<Item = PathErrorStep>,

Wraps the error with a path.

Panics

Will panic if trying to wrap error path for error types that don’t support path wrapping.

pub fn insert_path<P>(self, path: P, index: usize) -> Self
where P: IntoIterator<Item = PathErrorStep>,

Inserts a path at the specified index.

Panics

Will panic if trying to insert error path for error types that don’t support path insertion.

pub fn wrap_field<F: Display>(self, field: F) -> Self

Wraps the error with a field.

pub fn wrap_index(self, index: usize) -> Self

Wraps error with an index.

pub fn wrap_key<K: Display>(self, key: K) -> Self

Wraps error with a key.

pub fn wrap_field_index<F>(self, field: F, index: usize) -> Self
where F: Display,

Wraps error with a field and index.

pub fn wrap_field_key<F, K>(self, field: F, key: K) -> Self
where F: Display, K: Display,

Wraps error with a field and key.

pub fn wrap_request<N: Display>(self, name: N) -> Self

Wraps error for a request.

pub fn code(&self) -> Code

Returns the error code.

pub fn details(&self) -> Vec<Any>

Returns the error details.

Panics

Will panic if unable to convert bad request details to protobuf Any type.