pub enum RequestError {
BadRequest {
name: String,
violations: Vec<PathError>,
},
Path(PathError),
Generic(GenericErrorBox),
Encode(EncodeError),
Decode(DecodeError),
}Expand description
Request error types.
Variants
BadRequest
Invalid request with field violations.
Path(PathError)
Path-specific error.
Generic(GenericErrorBox)
Generic error.
Encode(EncodeError)
Encode error.
Decode(DecodeError)
Decode error.
Implementations
Sourceimpl RequestError
impl RequestError
Sourcepub fn bad_request<N, V, F, E>(name: N, violations: V) -> Self
pub fn bad_request<N, V, F, E>(name: N, violations: V) -> Self
Creates a bad request error.
Sourcepub fn generic<E: Into<GenericErrorBox>>(error: E) -> Self
pub fn generic<E: Into<GenericErrorBox>>(error: E) -> Self
Creates a generic error.
Sourcepub fn field_index<F, E>(field: F, index: usize, error: E) -> Self
pub fn field_index<F, E>(field: F, index: usize, error: E) -> Self
Creates a field index error.
Sourcepub fn field_parse<F, E>(field: F, error: E) -> Self
pub fn field_parse<F, E>(field: F, error: E) -> Self
Creates a field parse error.
Sourcepub fn index<E>(index: usize, error: E) -> Selfwhere
E: Into<GenericErrorBox>,
pub fn index<E>(index: usize, error: E) -> Selfwhere
E: Into<GenericErrorBox>,
Creates an index error.
Sourcepub fn wrap_path<P>(self, path: P) -> Selfwhere
P: IntoIterator<Item = PathErrorStep>,
pub fn wrap_path<P>(self, path: P) -> Selfwhere
P: IntoIterator<Item = PathErrorStep>,
Wraps the error with a path.
Panics
Will panic if trying to wrap error path for error types that don’t support path wrapping.
Sourcepub fn insert_path<P>(self, path: P, index: usize) -> Selfwhere
P: IntoIterator<Item = PathErrorStep>,
pub fn insert_path<P>(self, path: P, index: usize) -> Selfwhere
P: IntoIterator<Item = PathErrorStep>,
Inserts a path at the specified index.
Panics
Will panic if trying to insert error path for error types that don’t support path insertion.
Sourcepub fn wrap_field<F: Display>(self, field: F) -> Self
pub fn wrap_field<F: Display>(self, field: F) -> Self
Wraps the error with a field.
Sourcepub fn wrap_index(self, index: usize) -> Self
pub fn wrap_index(self, index: usize) -> Self
Wraps error with an index.
Sourcepub fn wrap_field_index<F>(self, field: F, index: usize) -> Selfwhere
F: Display,
pub fn wrap_field_index<F>(self, field: F, index: usize) -> Selfwhere
F: Display,
Wraps error with a field and index.
Sourcepub fn wrap_field_key<F, K>(self, field: F, key: K) -> Self
pub fn wrap_field_key<F, K>(self, field: F, key: K) -> Self
Wraps error with a field and key.
Sourcepub fn wrap_request<N: Display>(self, name: N) -> Self
pub fn wrap_request<N: Display>(self, name: N) -> Self
Wraps error for a request.